@@ -65,9 +65,10 @@ def get_commits_of_repo(repo,from_date=None,to_date=None,headers={}):
     return req.json()
 
 def filewebinfo(repo, filepath, lineno=None,commit='master'):
-    baseurl = "https://github.com/{0}/blob/{1}/{2}".format(repo,commit,filepath)
+    owner,reponame = repo.split('/')
+    baseurl = "https://github.com/{0}/blob/{1}/{2}".format(repo,commit,filepath.replace(str(reponame)+"/",'',1))
     if lineno:
-        baseurl += "#L{0}".format(lineno)
+        baseurl += "#L{0}".format(int(lineno))
     
     return baseurl
 
